@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader;
 # ABSTRACT: Classe de base pour le chargement de notices biblio/autorité
-$Koha::Contrib::Sudoc::Loader::VERSION = '2.06';
+$Koha::Contrib::Sudoc::Loader::VERSION = '2.07';
 use Moose;
 use Modern::Perl;
 use MARC::Moose::Reader::File::Iso2709;
@@ -64,6 +64,13 @@ sub BUILD {
         mode      => '>>',
         binmode   => ':encoding(utf8)',
     ) );
+    $self->log->add( Log::Dispatch::File->new(
+        name      => 'file2',
+        min_level => $self->sudoc->c->{loading}->{log}->{level},
+        filename  => $self->sudoc->root . "/var/log/email.log",
+        mode      => '>>',
+        #binmode   => ':encoding(utf8)',
+    ) );
 
 
     # Instanciation du converter
@@ -81,6 +88,7 @@ sub BUILD {
 }
 
 
+
 # C'est cette méthodes qui est surchargée par les sous-classes dédiées au
 # traitement des notices biblio et d'autorités
 sub handle_record {
@@ -111,9 +119,10 @@ sub run {
      );
     $self->log->notice("** Test ** Le fichier " . $self->file . " n'a pas été chargé\n")
         unless $self->doit;
-    $self->log->debug("\n");
+    $self->log->notice("\n");
 }
 
+
 1;
 
 __END__
@@ -128,7 +137,7 @@ Koha::Contrib::Sudoc::Loader - Classe de base pour le chargement de notices bibl
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 AUTHOR
 
