@@ -1,11 +1,11 @@
 package Koha::Contrib::Sudoc::TransferDaemon;
 # ABSTRACT: Service de transfert de fichiers
-$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.06';
+$Koha::Contrib::Sudoc::TransferDaemon::VERSION = '2.07';
 use Moose;
 use Modern::Perl;
-use AnyEvent;
 use Mail::Box::Manager;
 use DateTime;
+use Path::Tiny;
 use Log::Dispatch;
 use Log::Dispatch::Screen;
 use Log::Dispatch::Syslog;
@@ -57,13 +57,11 @@ sub start {
     my $self = shift;
 
     $self->log->notice( "Démarrage du service de transfert ABES\n" );
-    my $timeout = $self->sudoc->c->{trans}->{timeout};
-    my $idle = AnyEvent->timer(
-        after    => $timeout,
-        interval => $timeout,
-        cb       => sub { $self->transfert_abes(); }
-    );
-    AnyEvent->condvar->recv;
+    my $timeout = $self->sudoc->c->{trans}->{timeout} * 60;
+    while (1) {
+        $self->check_mbox();
+        sleep($timeout);
+    }
 }
 
 
@@ -89,15 +87,14 @@ sub send_gtd_email {
             "GTD_REMOTE_DIR = staged\n",
     );
 
-    my $message = Mail::Message->new(
-        head => $head,
-        body => $body );
+    my $message = Mail::Message->new(head => $head, body => $body);
     $message->send;
 }
 
 
-# Envoi à l'ABES d'un email GTD en réponse à un message 'status 9'. Celui-ci contient le numéro du job
-sub send_gtd {
+# Envoi à l'ABES d'un email GTD en réponse à un message 'status 9'. Celui-ci
+# contient le numéro du job
+sub ask_sending {
     my ($self, $msg) = @_;
 
     # Récupération dans le courriel de l'ABES des info dont on a besoin pour
@@ -105,23 +102,46 @@ sub send_gtd {
     my $body = $msg->body;
     my ($jobid) = $body =~ /JobId\s*:\s*(\d*)/;
 
-    $self->send_gtd_email($jobid);
-
     my $iln = $self->sudoc->c->{iln};
     my $year = DateTime->now->year;
     $self->log->notice(
-        "Réception 'status 9'. Envoi GTD: ILN $iln, job $jobid, année $year\n" );
+        "Réception 'status 9'. Envoi GTD: ILN $iln, job $jobid, année $year\n" );    
+
+    $self->send_gtd_email($jobid);
 }
 
 
-sub move_to_waiting {
+# La transfert est terminé. Les fichiers sont déplacés en waiting. Ils sont
+# chargés si configuré ainsi.
+sub transfer_ended {
     my $self = shift;
+    my $sudoc = $self->sudoc;
+    my $c = $sudoc->c;
     $self->log->notice("Réception 'status 0'. Fin transfert: 'staged' déplacé en 'waiting'\n");
-    $self->sudoc->spool->staged_to_waiting();
+    $sudoc->spool->staged_to_waiting();
+    return unless $c->{loading}->{auto};
+
+    # Chargement
+    $self->log->notice("Chargement automatique des fichiers reçus\n");
+    $sudoc->load_waiting();
+
+    # Envoi des log s'il y en a
+    my $logfile = $sudoc->root . "/var/log/email.log";
+    return unless -e $logfile;
+    my $head = Mail::Message::Head->new;
+    $head->add( From    => $c->{loading}->{log}->{from} );
+    $head->add( To      => $c->{loading}->{log}->{to}   );
+    $head->add( Subject => 'Chargeur Sudoc Koha Tamil'  );
+    my $body = Mail::Message::Body::Lines->new( data => path($logfile)->slurp );
+    my $message = Mail::Message->new(head => $head, body => $body);
+    $message->send;
 }
 
 
-sub transfert_abes {
+# Contrôle la MBOX contenant les messages envoyés par l'ABES:
+# status 9: Des fichiers sont prêts à être transférés par l'ABES
+# status 0: Fin transfert de fichiers
+sub check_mbox {
     my $self = shift;
 
     # Ne rien faire si la MBOX est vide
@@ -131,8 +151,8 @@ sub transfert_abes {
     my $folder = $self->mgr->open( folder => $mbox, access => 'rw' );
     for my $message ($folder->messages) {
         for ($message->subject()) {
-            if    ( /status is 9/ ) { $self->send_gtd($message);        }
-            elsif ( /status: 0/ )   { $self->move_to_waiting(); }
+            if    ( /status is 9/ ) { $self->ask_sending($message); }
+            elsif ( /status: 0/ )   { $self->transfer_ended();      }
         }
         $message->delete;
     }
@@ -153,7 +173,7 @@ Koha::Contrib::Sudoc::TransferDaemon - Service de transfert de fichiers
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 AUTHOR
 
